<?php

function locker_drush_command() {
  $items  = array();
  $items['lock'] = array(
    'callback'    => 'locker_drush_lock',
    'description' => dt('Lock site'),
    'arguments'   => array(
      'passphrase'    => "Enter your desired passphrase to unlock the site.",
      'username'      => "Enter your desired username to unlock the site.",
      'password'      => "Enter your desired password to unlock the site.",
    ),
    'examples' => array(
      'drush lock u username password' => 'Lock your Drupal site with username = username & password = password.',
      'drush lock passphrase' => 'Lock your Drupal site with passphrase = passphrase.',
    ),
  );
  $items['unlock'] = array(
    'callback'    => 'locker_drush_unlock',
    'description' => dt('Unlock site'),
    'examples' => array(
      'drush unlock' => 'Unlock your Drupal site.',
    ),
  );
  return $items;
}

/**
 * Lock drupal site with drush command.
 */
function locker_drush_lock($passphrase = '', $user = '', $pass = '') {
  $locker_access_options = '';

  if (empty($passphrase)) {
    $options = array(
      '1' => t('Passphrase'),
      '2' => t('Username/password'),
    );
    $choiced_option = drush_choice($options, t('
    Locker module - usage:
    
    drush lock u username password	- to lock site with username and password
    drush lock passphrase 		- to lock site only with passphrase
    drush unlock			- to unlock site

Please choose a option.'));

    if ($choiced_option == 0) {
      drupal_set_message(
        t('Error! Process cancelled.')
      );
    } else if ($choiced_option == 1) {
      $passphrase = drush_prompt(t('Please choose a passphrase'));
    } else if ($choiced_option == 2) {
      $passphrase = 'u';
      $user = drush_prompt(t('Please choose a username'));
      $pass = drush_prompt(t('Please choose a password'));
    } 
  }

  if (isset($passphrase)) {
    if (empty($passphrase)) {
      drupal_set_message(
        t('Error! No passphrase found.')
      );
    } else if ($passphrase == 'u') {
      $passmd5 = md5($pass);
      variable_set('locker_user', $user);
      variable_set('locker_password', $passmd5);
      $locker_access_options = 'user_pass';
    } else {
      variable_set('locker_passphrase', md5($passphrase));
      $locker_access_options = 'passphrase';
    }
  }

  if (!empty($locker_access_options)) {
    variable_set('locker_access_options', $locker_access_options);
    variable_set('locker_site_locked', 'yes');
    db_query("DELETE FROM sessions WHERE session LIKE 'locker_unlocked%';")->execute();
    variable_del('locker_login_error');
    drupal_set_message(
      t('Successfully locked.')
    );
  }
}

/**
 * Unlock drupal site with drush command.
 */
function locker_drush_unlock() {
  variable_del('locker_user');
  variable_set('locker_site_locked', NULL);
  variable_del('locker_password');
  variable_del('locker_passphrase');
  db_query("DELETE FROM sessions WHERE session LIKE 'locker_unlocked%';")->execute();
  drupal_set_message(
    t('Successfully unlocked.')
  );
}
